@@ -45,13 +45,14 @@ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.  */
 # define __LITTLE_ENDIAN	1234
 # define __BIG_ENDIAN		4321
 # if defined(__hpux)
-#   define __BYTE_ORDER __LITTLE_ENDIAN
+#   define __BYTE_ORDER __BIG_ENDIAN
 # else
 #   error Host has unknown byte-order.
 # endif
 #endif
 
 #ifdef __GNUC__
+# define UNUSED		__attribute__((unused))
 # if (__GNUC__ > 3) || (__GNUC__ == 3 && __GNUC_MINOR__ > 2)
 #  define HIDDEN	__attribute__((visibility ("hidden")))
 # else
@@ -65,6 +66,7 @@ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.  */
 #  define unlikely(x)	(x)
 # endif
 #else
+# define UNUSED
 # define HIDDEN
 # define likely(x)	(x)
 # define unlikely(x)	(x)
@@ -72,6 +74,8 @@ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.  */
 
 #ifdef DEBUG
 # define UNW_DEBUG	1
+#else
+# define UNW_DEBUG	0
 #endif
 
 #if UNW_DEBUG
@@ -81,7 +85,8 @@ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.  */
 # define dprintf(format...) \
     fprintf (stderr, format)
 # ifdef __GNUC__
-#  define inline	__attribute__ ((unused))
+#  undef inline
+#  define inline	UNUSED
 # endif
 #else
 # define debug(level,format...)
@@ -103,21 +108,37 @@ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.  */
 #define mutex_lock(l)	(pthread_mutex_lock ? pthread_mutex_lock (l) : 0)
 #define mutex_unlock(l)	(pthread_mutex_unlock ? pthread_mutex_unlock (l) : 0)
 
-#ifdef HAVE_IA64INTRIN_H
-# define HAVE_CMPXCHG
-# include <ia64intrin.h>
+#ifdef HAVE_ATOMIC_OPS_H
+# include <atomic_ops.h>
+# define cmpxchg_ptr(_ptr,_o,_n)	AO_compare_and_swap((AO_T *)_ptr, \
+							    (AO_T) (_o),  \
+							    (AO_T) (_n))
+# define fetch_and_add1(_ptr)		AO_fetch_and_add1(_ptr)
+   /* GCC 3.2.0 on HP-UX crashes on cmpxchg_ptr() */
+#  if !(defined(__hpux) && __GNUC__ == 3 && __GNUC_MINOR__ == 2)
+#   define HAVE_CMPXCHG
+#  endif
+# define HAVE_FETCH_AND_ADD1
+#else
+# ifdef HAVE_IA64INTRIN_H
+#  include <ia64intrin.h>
   /*
    * ecc v7.0 is broken: it's missing __sync_val_compare_and_swap()
    * even though the ia64 ABI requires it.  Work around it:
    */
-# ifndef __sync_val_compare_and_swap
-#  define __sync_val_compare_and_swap(x,y,z)		\
+#  ifndef __sync_val_compare_and_swap
+#   define __sync_val_compare_and_swap(x,y,z)				\
 	_InterlockedCompareExchange64_rel(x,y,z)
-# endif
+#  endif
 
-# define cmpxchg_ptr(_ptr,_o,_n)					\
+#  define cmpxchg_ptr(_ptr,_o,_n)					\
 	((void *) __sync_val_compare_and_swap((volatile long *) (_ptr),	\
-					      (long) (_o), (long) (_n)))
+					      (long) (_o), (long) (_n))	\
+	 == (_o))
+#  define fetch_and_add1(_ptr)		__sync_fetch_and_add(_ptr, 1)
+#  define HAVE_CMPXCHG
+#  define HAVE_FETCH_AND_ADD1
+# endif
 #endif
 
 #define UNWI_OBJ(fn)	  UNW_PASTE(UNW_PREFIX,UNW_PASTE(I,fn))
