@@ -2,7 +2,7 @@
 
 HIDDEN int hppa_needs_initialization = 1;
 
-#ifdef UNW_DEBUG
+#if UNW_DEBUG
 HIDDEN int tdep_debug_level;
 #endif
 
